/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the MIPS Magnum 3000 keyboard.
 * By Cliff Marcellus <cliff@phys.ucalgary.ca>.
 */

static const KeyCode mag3k_codes [] = {

  /* Row 0 */
  9, 17, 25, 33,
  41, 49, 57, 65,
  73, 81, 88, 96,
  97, 0,

  /* Row 2 */
  10, 24, 32, 40, 39, 48, 56, 63, 64, 72, 71, 80, 87, 16, 104,
  120, 121, 128, 126,

  /* Row 3 */
  15, 23, 31, 38, 47, 46, 55, 62, 69, 70, 79, 86, 93, 94, 102,
  110, 119, 127, 134,
  
  /* Row 4 */
  19, 30, 29, 37, 45, 54, 53, 61, 68, 77, 78, 84, 92, 89,
  109, 117, 118, 111,

  /* Row 5 */
  20, 28, 36, 35, 44, 52, 51, 60, 67, 75, 76, 91, 101, 90,
  107, 116, 124, 123,
  
  /* Row 6 */
  22, 27, 43, 59, 99, 98, 108,
  114, 115
};
